@@ -1,31 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2013 Deepin Technology Co., Ltd.
- *               2011 ~ 2013 Long Wei
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             bluth <yuanchenglu001@gmail.com>
- *             Hualet <mr.asianwang@gmail.com>
- *             Long Wei <yilang2007lw@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *             Long Wei <yilang2007lw@gamil.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -37,7 +12,8 @@
 
 #include <systemd/sd-login.h>
 
-struct user_session_dbus {
+struct user_session_dbus
+{
     gchar *session_path;
     gchar *seat_path;
     gchar *username;
@@ -50,10 +26,12 @@ get_user_name()
 
     struct passwd *pw = NULL;
     pw = getpwuid(getuid());
-    if (pw != NULL) {
+    if (pw != NULL)
+    {
         username = g_strdup(pw->pw_name);
-
-    } else {
+    }
+    else
+    {
         g_warning("switchtogreeter:get user name failed\n");
     }
 
@@ -71,14 +49,15 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
 
     usd->seat_path = NULL;
     display_proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SYSTEM,
-                    G_DBUS_PROXY_FLAGS_NONE,
-                    NULL,
-                    "org.freedesktop.DisplayManager",
-                    "/org/freedesktop/DisplayManager",
-                    "org.freedesktop.DisplayManager",
-                    NULL,
-                    &error);
-    if (error != NULL) {
+                                                  G_DBUS_PROXY_FLAGS_NONE,
+                                                  NULL,
+                                                  "org.freedesktop.DisplayManager",
+                                                  "/org/freedesktop/DisplayManager",
+                                                  "org.freedesktop.DisplayManager",
+                                                  NULL,
+                                                  &error);
+    if (error != NULL)
+    {
         g_warning("switchtogreeter:lightdm dbus %s\n", error->message);
         g_error_free(error);
         return NULL;
@@ -86,7 +65,8 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
     error = NULL;
 
     sessions_prop_var = g_dbus_proxy_get_cached_property(display_proxy, "Sessions");
-    if (sessions_prop_var == NULL) {
+    if (sessions_prop_var == NULL)
+    {
         g_warning("switchtogreeter:get sessions list failed\n");
         g_object_unref(display_proxy);
         return NULL;
@@ -94,27 +74,30 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
     g_object_unref(display_proxy);
 
     sessions = g_variant_get_objv(sessions_prop_var, &length);
-    if (sessions == NULL) {
+    if (sessions == NULL)
+    {
         g_warning("switchtogreeter:parse sessions list failed\n");
         g_variant_unref(sessions_prop_var);
         return NULL;
     }
 
-    for (guint i = 0; i < length; ++i) {
+    for (guint i = 0; i < length; ++i)
+    {
 
         GDBusProxy *session_proxy = NULL;
         GVariant *username_prop_var = NULL;
         gchar *user_name = NULL;
 
         session_proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SYSTEM,
-                        G_DBUS_PROXY_FLAGS_NONE,
-                        NULL,
-                        "org.freedesktop.DisplayManager",
-                        sessions[i],
-                        "org.freedesktop.DisplayManager.Session",
-                        NULL,
-                        &error);
-        if (error != NULL) {
+                                                      G_DBUS_PROXY_FLAGS_NONE,
+                                                      NULL,
+                                                      "org.freedesktop.DisplayManager",
+                                                      sessions[i],
+                                                      "org.freedesktop.DisplayManager.Session",
+                                                      NULL,
+                                                      &error);
+        if (error != NULL)
+        {
             g_warning("switchtogreeter:lightdm session dbus %s\n", error->message);
             g_error_free(error);
             continue;
@@ -122,8 +105,10 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
         error = NULL;
 
         username_prop_var = g_dbus_proxy_get_cached_property(session_proxy, "UserName");
-        if (username_prop_var == NULL) {
-            if (error != NULL) {
+        if (username_prop_var == NULL)
+        {
+            if (error != NULL)
+            {
                 g_warning("switchtogreeter:get username %s\n", error->message);
                 g_error_free(error);
             }
@@ -132,26 +117,33 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
         }
 
         user_name = g_variant_dup_string(username_prop_var, NULL);
-        if (user_name == NULL) {
+        if (user_name == NULL)
+        {
             g_warning("switchtogreeter:get username from session failed\n");
             g_object_unref(session_proxy);
             g_variant_unref(username_prop_var);
             continue;
         }
 
-        if (g_strcmp0(username, user_name) == 0) {
+        if (g_strcmp0(username, user_name) == 0)
+        {
             GVariant *seat_prop_var = NULL;
             gsize seat_path_length = 0;
 
             seat_prop_var = g_dbus_proxy_get_cached_property(session_proxy, "Seat");
-            if (seat_prop_var != NULL) {
-                usd->seat_path  = g_variant_dup_string(seat_prop_var, &seat_path_length);
+            if (seat_prop_var != NULL)
+            {
+                usd->seat_path = g_variant_dup_string(seat_prop_var, &seat_path_length);
                 usd->session_path = g_strdup_printf("%s", sessions[i]);
                 usd->username = username;
-            } else {
+            }
+            else
+            {
                 g_warning("switchtogreeter:get seat path failed for user %s\n", username);
             }
-        } else {
+        }
+        else
+        {
             continue;
         }
 
@@ -168,7 +160,8 @@ get_seat_path(gchar *username, struct user_session_dbus *usd)
 
 static uid_t name_to_uid(char const *name)
 {
-    if (!name) {
+    if (!name)
+    {
         return (unsigned int)-1;
     }
 
@@ -180,8 +173,7 @@ static uid_t name_to_uid(char const *name)
 // ret:
 // 0: change to another session
 // 1: stay current session
-int
-switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
+int switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
 {
     int ret = 1;
     char **sessions = NULL;
@@ -194,21 +186,23 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
     GDBusProxy *login1_proxy = NULL;
     GError *error = NULL;
 
-    if (!g_variant_is_object_path(seat_path)) {
+    if (!g_variant_is_object_path(seat_path))
+    {
         g_warning("switchtogreeter:invalid object path\n");
         return 1;
     }
 
     seat_proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SYSTEM,
-                 G_DBUS_PROXY_FLAGS_NONE,
-                 NULL,
-                 "org.freedesktop.DisplayManager",
-                 seat_path,
-                 "org.freedesktop.DisplayManager.Seat",
-                 NULL,
-                 &error);
+                                               G_DBUS_PROXY_FLAGS_NONE,
+                                               NULL,
+                                               "org.freedesktop.DisplayManager",
+                                               seat_path,
+                                               "org.freedesktop.DisplayManager.Seat",
+                                               NULL,
+                                               &error);
 
-    if (error != NULL) {
+    if (error != NULL)
+    {
         g_warning("switchtogreeter:seat proxy %s\n", error->message);
         g_error_free(error);
         return 1;
@@ -217,7 +211,8 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
 
     printf("current seat path: %s\n", seat_path);
     strlist = g_strsplit(seat_path, "/", -1);
-    while (*strlist) {
+    while (*strlist)
+    {
         cur_seat = *strlist;
         strlist++;
     }
@@ -226,16 +221,19 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
     printf("usd->session_path: %s\n", usd->session_path);
     printf("usd->username: %s\n", usd->username);
 
-    if (usd->session_path != NULL && usd->username != NULL) {
+    if (usd->session_path != NULL && usd->username != NULL)
+    {
         GDBusProxy *login1_session_proxy = NULL;
         GVariant *type_prop_var = NULL;
         gchar *type = NULL;
         char objpath[256];
 
         sd_uid_get_sessions(name_to_uid(usd->username), 0, &sessions);
-        while (*sessions) {
+        while (*sessions)
+        {
             sd_session_get_display(*sessions, &display);
-            if (getenv("WAYLAND_DISPLAY") != NULL) {
+            if (getenv("WAYLAND_DISPLAY") != NULL)
+            {
                 memset(objpath, 0, 256 * sizeof(char));
                 sprintf(objpath, "/org/freedesktop/login1/session/_3%s", *sessions);
                 login1_session_proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SYSTEM,
@@ -247,7 +245,8 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
                                                                      NULL,
                                                                      &error);
 
-                if (error != NULL) {
+                if (error != NULL)
+                {
                     g_warning("switchtogreeter:login1_session_proxy %s\n", error->message);
                     g_error_free(error);
                     g_object_unref(login1_session_proxy);
@@ -257,7 +256,8 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
                 error = NULL;
 
                 type_prop_var = g_dbus_proxy_get_cached_property(login1_session_proxy, "Type");
-                if (type_prop_var == NULL) {
+                if (type_prop_var == NULL)
+                {
                     g_variant_unref(type_prop_var);
                     g_object_unref(login1_session_proxy);
                     return 1;
@@ -265,15 +265,19 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
 
                 type = g_variant_dup_string(type_prop_var, NULL);
 
-                if (NULL == display && strcmp(type, "wayland") != 0){
+                if (NULL == display && strcmp(type, "wayland") != 0)
+                {
                     sessions++;
                     g_free(type);
                     g_variant_unref(type_prop_var);
                     g_object_unref(login1_session_proxy);
                     continue;
                 }
-            } else {
-                if (NULL == display){
+            }
+            else
+            {
+                if (NULL == display)
+                {
                     sessions++;
                     continue;
                 }
@@ -281,7 +285,8 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
 
             sd_session_get_seat(*sessions, &seat);
             printf("session display %s %s\n", *sessions, display);
-            if (seat != NULL && (0 == g_ascii_strcasecmp(seat, cur_seat))) {
+            if (seat != NULL && (0 == g_ascii_strcasecmp(seat, cur_seat)))
+            {
                 new_user_session = *sessions;
                 printf("switchtogreeter: find sessions path %s %s \n", new_user_session, seat);
                 break;
@@ -289,26 +294,28 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
             sessions++;
         }
 
-        if (getenv("WAYLAND_DISPLAY") != NULL) {
+        if (getenv("WAYLAND_DISPLAY") != NULL)
+        {
             g_free(type);
             g_variant_unref(type_prop_var);
             g_object_unref(login1_session_proxy);
         }
 
-        if (NULL == new_user_session) {
+        if (NULL == new_user_session)
+        {
             g_error("switchtogreeter: can not find user sessions %s \n", usd->username);
             return 1;
         }
         printf("find user session: %s\n", new_user_session);
 
         login1_proxy = g_dbus_proxy_new_for_bus_sync(G_BUS_TYPE_SYSTEM,
-                       G_DBUS_PROXY_FLAGS_NONE,
-                       NULL,
-                       "org.freedesktop.login1",
-                       "/org/freedesktop/login1",
-                       "org.freedesktop.login1.Manager",
-                       NULL,
-                       &error);
+                                                     G_DBUS_PROXY_FLAGS_NONE,
+                                                     NULL,
+                                                     "org.freedesktop.login1",
+                                                     "/org/freedesktop/login1",
+                                                     "org.freedesktop.login1.Manager",
+                                                     NULL,
+                                                     &error);
         g_dbus_proxy_call_sync(login1_proxy,
                                "ActivateSession",
                                g_variant_new("(s)", new_user_session),
@@ -317,7 +324,9 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
                                NULL,
                                &error);
         ret = 0;
-    } else if (usd->username != NULL) {
+    }
+    else if (usd->username != NULL)
+    {
         printf("SwitchToUser\n");
         usd->session_path = "";
         g_dbus_proxy_call_sync(seat_proxy,
@@ -328,7 +337,9 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
                                NULL,
                                &error);
         ret = 1;
-    } else {
+    }
+    else
+    {
         g_dbus_proxy_call_sync(seat_proxy,
                                "SwitchToGreeter",
                                g_variant_new("()"),
@@ -339,7 +350,8 @@ switch_to_greeter(gchar *seat_path, struct user_session_dbus *usd)
         ret = 1;
     }
 
-    if (error != NULL) {
+    if (error != NULL)
+    {
         g_warning("switchtogreeter:seat switchtogreeter %s\n", error->message);
         g_error_free(error);
     }
@@ -362,7 +374,8 @@ int main(int argc G_GNUC_UNUSED, char **argv G_GNUC_UNUSED)
     new_user.session_path = NULL;
 
     current_username = get_user_name();
-    if (current_username == NULL) {
+    if (current_username == NULL)
+    {
         g_warning("switch to greeter:username is NULL\n");
         return 1;
     }
@@ -370,24 +383,28 @@ int main(int argc G_GNUC_UNUSED, char **argv G_GNUC_UNUSED)
     current_user.username = current_username;
     get_seat_path(current_username, &current_user);
 
-
-    if (argc == 2) {
+    if (argc == 2)
+    {
         new_username = argv[1];
     }
 
-    new_user.username =  new_username;
+    new_user.username = new_username;
     get_seat_path(new_user.username, &new_user);
-    if (new_user.seat_path == NULL) {
+    if (new_user.seat_path == NULL)
+    {
         g_info("switch to greeter:seat path is NULL\n");
     }
 
-    if (current_user.seat_path != NULL) {
+    if (current_user.seat_path != NULL)
+    {
         current_seat_path = current_user.seat_path;
     }
-    if (new_user.seat_path != NULL) {
+    if (new_user.seat_path != NULL)
+    {
         current_seat_path = new_user.seat_path;
     }
-    if (current_seat_path == NULL) {
+    if (current_seat_path == NULL)
+    {
         g_error("switch to greeter:current user seat path is NULL\n");
         g_free(current_username);
         return 1;
@@ -400,4 +417,3 @@ int main(int argc G_GNUC_UNUSED, char **argv G_GNUC_UNUSED)
 
     return ret;
 }
-
